Package 'rk.exporter'
| Title: |
RKWard Plugin Suite for Batch Exporting lists of ggplot2 and
flextable objects to individual files or combined Office
documents (PDF, Word, PPTX). |
| Description: |
RKWard Plugin Suite for Batch Exporting lists of ggplot2
and flextable objects to individual files or combined Office
documents (PDF, Word, PPTX). |
| Authors: |
Alfonso Cano Robles |
| Maintainer: |
Alfonso Cano Robles <[email protected]> |
| License: |
GPL (>= 3) |
| Version: |
0.0.1 |
| Built: |
2026-05-25 06:52:35 UTC |
| Source: |
https://github.com/AlfCano/rk.exporter |
Help Index